<?php

/**
 * Team.
 *
 * @package Sympathy
 * @author QTC Media
 * @link http://qtcmedia.com
 */
/* ---------------------------------------------------------------------------
 * Create new post type
 * --------------------------------------------------------------------------- */
function sympathy_photo_team_post_type() {
    $sympathy_smof_data = get_option('sympathy_smof_data');
    $team_item_slug = 'team';
    if (isset($sympathy_smof_data['qtc_team_slug'])) {
        $team_item_slug = $sympathy_smof_data['qtc_team_slug'];
    }
    $labels = array(
        'name' => __('Team', 'sympathy'),
        'singular_name' => __('Team', 'sympathy'),
        'add_new' => __('Add New', 'sympathy'),
        'add_new_item' => __('Add Team', 'sympathy'),
        'edit_item' => __('Edit Team', 'sympathy'),
        'new_item' => __('New Team', 'sympathy'),
        'view_item' => __('View Team', 'sympathy'),
        'search_items' => __('Search Team', 'sympathy'),
        'not_found' => __('No photo gallery found', 'sympathy'),
        'not_found_in_trash' => __('No photo gallery found in Trash', 'sympathy'),
        'parent_item_colon' => ''
    );

    $args = array(
        'labels' => $labels,
        'menu_icon' => 'dashicons-admin-users',
        'public' => true,
        'publicly_queryable' => true,
        'show_ui' => true,
        'query_var' => true,
        'capability_type' => 'post',
        'hierarchical' => true,
        'menu_position' => null,
        'rewrite' => array('slug' => $team_item_slug, 'with_front' => true),
        'supports' => array('title', 'editor', 'page-attributes', 'thumbnail', 'excerpt'),
        'has_archive' => true,
    );

    sympathy_custom_reg_post_type('team', $args);

    sympathy_custom_reg_taxonomy('team-types', 'team', array(
        'hierarchical' => true,
        'label' => __('Team categories', 'sympathy'),
        'singular_label' => __('Team category', 'sympathy'),
        'rewrite' => true,
        'query_var' => true
    ));
}

add_action('init', 'sympathy_photo_team_post_type', 7);



// Metaboxes
if (!function_exists('sympathy_team_metaboxes')) {

    function sympathy_team_metaboxes() {
        add_meta_box('sympathy_info_team', 'Info Team', 'sympathy_info_team_output', 'team');
        add_meta_box('sympathy_social_info', 'Social Info', 'sympathy_social_info_output', 'team');
    }

}
add_action('add_meta_boxes', 'sympathy_team_metaboxes');

// Metaboxes callback
if (!function_exists('sympathy_info_team_output')) {

    function sympathy_info_team_output() {
        global $post;
        $position_team = get_post_meta($post->ID, 'position_team', true);
        $email_team = get_post_meta($post->ID, 'email_team', true);
        $phone_team = get_post_meta($post->ID, 'phone_team', true);
        ?>
        <div class="info-team">
            <ul>
                <li>
                    <label><?php echo __('Position:', 'sympathy'); ?></label>
                    <input type="text" id="position_team" name="position_team" value="<?php echo esc_attr($position_team); ?>" />
                </li>
                <li>
                    <label><?php echo __('Email:', 'sympathy'); ?></label>
                    <input type="email" id="email_team" name="email_team" value="<?php echo esc_attr($email_team); ?>" />
                </li>
                <li>
                    <label><?php echo __('Phone:', 'sympathy'); ?></label>
                    <input type="text" id="phone_team" name="phone_team" value="<?php echo esc_attr($phone_team); ?>" />
                </li>
            </ul>
        </div>
        <style>
            .info-team ul li textarea,
            .info-team ul li input{
                width: 100%;
            }
            .info-team label{
                display: block;
            }
        </style>
        <?php
    }

}
if (!function_exists('sympathy_social_info_output')) {

    function sympathy_social_info_output() {
        global $post;
        $facebook_team = get_post_meta($post->ID, 'facebook_team', true);
        $google_team = get_post_meta($post->ID, 'google_team', true);
        $twitter_team = get_post_meta($post->ID, 'twitter_team', true);
        $pinterest_team = get_post_meta($post->ID, 'pinterest_team', true);
        ?>
        <div class="social-info">
            <ul>
                <li>
                    <label><?php echo __('Facebook:', 'sympathy'); ?></label>
                    <input type="text" id="facebook_team" name="facebook_team" value="<?php echo esc_attr($facebook_team); ?>" />
                </li>
                <li>
                    <label><?php echo __('Google +:', 'sympathy'); ?></label>
                    <input type="text" id="google_team" name="google_team" value="<?php echo esc_attr($google_team); ?>" />
                </li>
                <li>
                    <label><?php echo __('Twitter:', 'sympathy'); ?></label>
                    <input type="text" id="email_team" name="twitter_team" value="<?php echo esc_attr($twitter_team); ?>" />
                </li>
                <li>
                    <label><?php echo __('Pinterest:', 'sympathy'); ?></label>
                    <input type="text" id="pinterest_team" name="pinterest_team" value="<?php echo esc_attr($pinterest_team); ?>" />
                </li>
            </ul>
        </div>
        <style>
            .social-info ul li input{
                width: 100%;
            }
            .social-info label{
                display: block;
            }
        </style>
        <?php
    }

}

// Save meta values
if (!function_exists('sympathy_save_team_metaboxes')) {

    function sympathy_save_team_metaboxes($post_id) {
        if (isset($_POST['position_team'])) {
            update_post_meta($post_id, 'position_team', $_POST['position_team']);
        }
        if (isset($_POST['email_team'])) {
            update_post_meta($post_id, 'email_team', $_POST['email_team']);
        }
        if (isset($_POST['phone_team'])) {
            update_post_meta($post_id, 'phone_team', $_POST['phone_team']);
        }

        if (isset($_POST['facebook_team'])) {
            update_post_meta($post_id, 'facebook_team', $_POST['facebook_team']);
        }
        if (isset($_POST['google_team'])) {
            update_post_meta($post_id, 'google_team', $_POST['google_team']);
        }
        if (isset($_POST['twitter_team'])) {
            update_post_meta($post_id, 'twitter_team', $_POST['twitter_team']);
        }
        if (isset($_POST['pinterest_team'])) {
            update_post_meta($post_id, 'pinterest_team', $_POST['pinterest_team']);
        }
    }

}
add_action('save_post', 'sympathy_save_team_metaboxes');


