<?php

if (!defined('ABSPATH'))
   exit;

/**
 * Import Demo Data
 *
 * @package Sympathy
 * @author QTC Media
 * @link http://qtcmedia.com
 */
class SYMPATHY_ImportData {

   /** ---------------------------------------------------------------------------
    * Constructor
    * ---------------------------------------------------------------------------- */
   function __construct() {

      //Add scripts
      add_action('admin_enqueue_scripts', array($this, 'sympathy_import_enqueue'));
      //Add ajax
      add_action('wp_ajax_sympathy_import', array($this, 'sympathy_import'));
   }

   /** ---------------------------------------------------------------------------
    * Add Import Scripts
    * ---------------------------------------------------------------------------- */
   function sympathy_import_enqueue() {
      wp_enqueue_style('sympathy_import', SYMPATHY_PLUGIN_IMPORT_URL . 'import.css', false, time(), 'all');
      wp_enqueue_script('sympathy_import', SYMPATHY_PLUGIN_IMPORT_URL . 'import.js', false, time(), true);
      wp_localize_script('sympathy_import', 'sympathy_ajax', array('ajaxurl' => admin_url('admin-ajax.php')));
   }

   function sympathy_set_options($options) {
      $options = json_decode($options['body'], true);
      update_option('sympathy_smof_data', $options);
   }

   /** ---------------------------------------------------------------------------
    * Import
    * ---------------------------------------------------------------------------- */
   function sympathy_import() {
      if (!defined('WP_LOAD_IMPORTERS'))
         define('WP_LOAD_IMPORTERS', true);

      if (!class_exists('WP_Importer')) {
         require_once ABSPATH . 'wp-admin/includes/class-wp-importer.php';
      }
      if (!class_exists('WP_Import')) {
         require_once SYMPATHY_PLUGIN_IMPORT_DIR . '/wordpress-importer.php';
      }
      $current_data = isset($_POST['demo']) ? $_POST['demo'] : '';
      switch ($current_data) {
         case 'options':
            $this->sympathy_import_options();
            break;
         case 'slider':
            $this->import_slider_revolution();
            break;
         case 'widget':
            $this->sympathy_import_widget();
            break;
         case 'menu':
            $this->sympathy_remove_menu();
            $this->sympathy_import_demo($current_data);
            $this->sympathy_set_menu();
            $this->set_page_setting();
            break;
         case 'form':
            $this->sympathy_import_demo($current_data);
            break;
         case 'icon':
            $this->sympathy_add_icon_ultimate();
            break;
         case 'media':
            $this->sympathy_import_demo($current_data);
            break;
         case 'content':
            $num_content = 18;
            for ($key = 1; $key <= $num_content; $key++) {
               $this->sympathy_import_content($key);
            }
            break;
         default:
            break;
      }

      die();
   }

   /** ---------------------------------------------------------------------------
    * Import Content
    * ---------------------------------------------------------------------------- */
   function set_page_setting() {
      //home main
      $home = get_page_by_title('Home');
      update_option('page_on_front', $home->ID);
      update_option('show_on_front', 'page');
      //update_post_meta($home->ID, 'titlebar', 'yes');
      //home 2
      $home2 = get_page_by_title('Home Two');
      //update_post_meta($home2->ID, 'titlebar', 'yes');
      // set the blog page
      $blog = get_page_by_title('Blog');
      update_option('page_for_posts', $blog->ID);
   }

   function sympathy_import_content($current_data) {
      $import = new WP_Import();

      $content_xml = SYMPATHY_PLUGIN_IMPORT_DIR . '/demo/data/content' . $current_data . '.xml';
      $import->fetch_attachments = true;

      ob_start();
      $import->import($content_xml);
      ob_end_clean();
   }

   function sympathy_import_demo($current_data) {
      $import = new WP_Import();

      $content_xml = SYMPATHY_PLUGIN_IMPORT_DIR . '/demo/data/' . $current_data . '.xml';
      
      $import->fetch_attachments = true;

      ob_start();
      $import->import($content_xml);
      ob_end_clean();
   }

   /** ---------------------------------------------------------------------------
    * Import Menu
    * ---------------------------------------------------------------------------- */
   function sympathy_remove_menu() {
      /* delete old menu and import new. */
      foreach (get_terms('nav_menu') as $nav) {
         wp_delete_nav_menu($nav->slug);
      }
   }

   function sympathy_set_menu() {

      /* Set menu */
      $locations = get_registered_nav_menus();

      if (!empty($locations)) {
         foreach ($locations as $locationId => $menuValue) {
            switch ($locationId) {
               case 'sympathy-main-menu':
                  $menu = get_term_by('name', 'Main Menu', 'nav_menu');
                  break;

               case 'sympathy-top-menu':
                  $menu = get_term_by('name', 'Top Menu', 'nav_menu');
                  break;

               case 'sympathy-footer-menu':
                  $menu = get_term_by('name', 'Footer Menu', 'nav_menu');
                  break;
            }
            if (isset($menu)) {
               $locations[$locationId] = $menu->term_id;
            }
            if ($locationId == 'sympathy-main-menu') {
               $list_items = wp_get_nav_menu_items($menu->term_id);
               //set menu group
               update_post_meta($list_items[1]->ID, '_menu_item_images', 'http://sympathy.qtcmedia.com/wp-content/uploads/2016/08/home-36x36.png');
               update_post_meta($list_items[1]->ID, '_menu_item_image_size', 'menu-36x36');
            }
         }

         set_theme_mod('nav_menu_locations', $locations);
      }
   }

   /** ---------------------------------------------------------------------------
    * Import Theme Options
    * ---------------------------------------------------------------------------- */
   function sympathy_import_options() {
      $options_json = SYMPATHY_PLUGIN_IMPORT_URL . '/demo/options.json';
      $options = wp_remote_get($options_json);
      if ($options) {
         $this->sympathy_set_options($options);
      }
   }

   /** ---------------------------------------------------------------------------
    * Import Widgets
    * ---------------------------------------------------------------------------- */
   function sympathy_import_widget() {
      $file_path = SYMPATHY_PLUGIN_IMPORT_URL . '/demo/widget_data.json';
      $file_data = wp_remote_get($file_path);
      $data = $file_data['body'];
      if ($data) {
         $this->sympathy_import_widget_data($data);
      }
   }

   /** ---------------------------------------------------------------------------
    * Parse JSON import file
    * ---------------------------------------------------------------------------- */
   function sympathy_import_widget_data($import_array) {
      global $wp_registered_sidebars;
      $json_data = $import_array;
      $json_data = json_decode($json_data, true);
      $sidebars_data = $json_data[0];
      $widget_data = $json_data[1];
      //print_r($widget_data);
     //       die();
      $new_widgets = array();
      $menu_footer = wp_get_nav_menu_object('Footer Menu');
      if (!empty($menu_footer)) {
         $menu_footer_id = $menu_footer->term_id;
         echo  $menu_footer_id;
         $widget_data['nav_menu'][4]['nav_menu'] = $menu_footer_id;
      }
      if ($sidebars_data):
         foreach ($sidebars_data as $import_sidebar => $import_widgets) :
            foreach ($import_widgets as $import_widget) :
               //if the sidebar exists
               if (isset($wp_registered_sidebars[$import_sidebar])) :
                  $title = trim(substr($import_widget, 0, strrpos($import_widget, '-')));
                  $index = trim(substr($import_widget, strrpos($import_widget, '-') + 1));
                  $current_widget_data = get_option('widget_' . $title);
                  $new_widget_name = $this->sympathy_get_new_widget_name($title, $index);
                  $new_index = trim(substr($new_widget_name, strrpos($new_widget_name, '-') + 1));
                  if (!empty($new_widgets[$title]) && is_array($new_widgets[$title])) {
                     while (array_key_exists($new_index, $new_widgets[$title])) {
                        $new_index++;
                     }
                  }
                  $current_sidebars[$import_sidebar][] = $title . '-' . $new_index;
                  if (array_key_exists($title, $new_widgets)) {
                     $new_widgets[$title][$new_index] = $widget_data[$title][$index];
                     $multiwidget = $new_widgets[$title]['_multiwidget'];
                     unset($new_widgets[$title]['_multiwidget']);
                     $new_widgets[$title]['_multiwidget'] = $multiwidget;
                  } else {
                     $current_widget_data[$new_index] = $widget_data[$title][$index];
                     $current_multiwidget = $current_widget_data['_multiwidget'];
                     $new_multiwidget = isset($widget_data[$title]['_multiwidget']) ? $widget_data[$title]['_multiwidget'] : false;
                     $multiwidget = ($current_multiwidget != $new_multiwidget) ? $current_multiwidget : 1;
                     unset($current_widget_data['_multiwidget']);
                     $current_widget_data['_multiwidget'] = $multiwidget;
                     $new_widgets[$title] = $current_widget_data;
                  }
               endif;
            endforeach;
         endforeach;
      endif;

      if (isset($new_widgets) && isset($current_sidebars)) {
         update_option('sidebars_widgets', $current_sidebars);
         foreach ($new_widgets as $title => $content)
            update_option('widget_' . $title, $content);
         return true;
      }
      return false;
   }

   /** ---------------------------------------------------------------------------
    * Get new widget name
    * ---------------------------------------------------------------------------- */
   function sympathy_get_new_widget_name($widget_name, $widget_index) {
      $current_sidebars = get_option('sidebars_widgets');
      $all_widget_array = array();
      foreach ($current_sidebars as $sidebar => $widgets) {
         if (!empty($widgets) && is_array($widgets) && $sidebar != 'wp_inactive_widgets') {
            foreach ($widgets as $widget) {
               $all_widget_array[] = $widget;
            }
         }
      }
      while (in_array($widget_name . '-' . $widget_index, $all_widget_array)) {
         $widget_index++;
      }
      $new_widget_name = $widget_name . '-' . $widget_index;
      return $new_widget_name;
   }

   /*
    * Import Slider Revolution
    */

   function import_slider_revolution() {

      if (class_exists('UniteBaseAdminClassRev')) {
         $path_plugin = ABSPATH . 'wp-content/plugins/option-sympathy/';
         require_once(ABSPATH . 'wp-content/plugins/revslider/admin/revslider-admin.class.php');
         if ($handle = opendir($path_plugin . 'import/slider')) {
            while (false !== ($entry = readdir($handle))) {
               if ($entry != "." && $entry != "..") {
                  $_FILES['import_file']['tmp_name'] = $path_plugin . 'import/slider/' . $entry;
                  $slider = new RevSlider();
                  ob_start();
                  $response = $slider->importSliderFromPost(true, true);
                  ob_end_clean();
               }
            }
            closedir($handle);
         }
         return true;
      }
      return false;
   }

   function sympathy_add_icon_ultimate() {
      if (class_exists('AIO_Icon_Manager')) {
         $path_plugin = ABSPATH . 'wp-content/plugins/option-sympathy/';
         require_once(ABSPATH . 'wp-content/plugins/Ultimate_VC_Addons/modules/Ultimate_Icon_Manager.php');
         if ($handle = opendir($path_plugin . 'import/icons')) {
            while (false !== ($entry = readdir($handle))) {
               if ($entry != "." && $entry != "..") {
                  $path = $path_plugin . 'import/icons/' . $entry;
                  $icons = new AIO_Icon_Manager();
                  ob_start();
                  $response = $icons->zip_flatten($path, array('\.eot', '\.svg', '\.ttf', '\.woff', '\.json', '\.css'));
                  if ($response) {
                     $icons->create_config();
                  }
                  ob_end_clean();
               }
            }
            closedir($handle);
         }
         return true;
      }
      return false;
   }

}

$sympathy_import = new SYMPATHY_ImportData();

