<?php
// Create Widget
add_action('widgets_init', 'register_client_widget');

function register_client_widget() {
    register_widget('Sympathy_Client_Widget');
}

/**
 * Create class Organian_Client_Widget
 */
class Sympathy_Client_Widget extends WP_Widget {

    function __construct() {
        parent::__construct(
                'sympathy_client_widget', // Base ID  
                esc_html__('Client', 'sympathy'), // Name  
                array(
            'classname' => 'client-top-footer sympathy-widget-client-list',
            'description' => esc_html__("Client widget for theme.", 'sympathy'),
                )
        );
    }

// end constructor 

    /**
     * create form option for widget
     */
    function form($instance) {
        parent::form($instance);

        $default = array(
            'posts_per_page' => '6',
            'el_class' => '',
        );

        $instance = wp_parse_args((array) $instance, $default);
        $posts_per_page = esc_attr($instance['posts_per_page']);
        $el_class = esc_attr($instance['el_class']);

        $randomclass_ana = rand(100, 10000);

        ob_start();
        ?>
        <p>
            <label for="<?php echo $this->get_field_id('posts_per_page'); ?>" style="display:block;"><?php echo esc_html__('Number of client to show. Ex: 0 => show all.', 'sympathy'); ?></label> 
            <input class="widefat posts_per_page" id="<?php echo $this->get_field_id('posts_per_page'); ?>" name="<?php echo $this->get_field_name('posts_per_page'); ?>" type="number" min="1" max="" step="1" value="<?php echo esc_attr($posts_per_page); ?>" />
        </p>

        <p>
            <label for="<?php echo $this->get_field_id('el_class'); ?>" style="display:block;"><?php echo esc_html__('Class', 'sympathy'); ?></label> 
            <input class="widefat el_class" id="<?php echo $this->get_field_id('el_class'); ?>" name="<?php echo $this->get_field_name('el_class'); ?>" type="text" value="<?php echo esc_attr($el_class); ?>" />
        </p>
        <?php
        $content_wid = ob_get_contents();
        ob_clean();
        ob_end_flush();
        echo $content_wid;
    }

    /**
     * save widget form
     */
    function update($new_instance, $old_instance) {
        parent::update($new_instance, $old_instance);

        $instance = $old_instance;

        $instance['posts_per_page'] = strip_tags($new_instance['posts_per_page']);
        $instance['el_class'] = strip_tags($new_instance['el_class']);

        return $instance;
    }

    /**
     * Show widget
     */
    function widget($args, $instance) {
        extract($args);
        echo $before_widget;
        $posts_per_page = absint($instance['posts_per_page']);
        $posts_per_page = $posts_per_page > 0 ? $posts_per_page : -1;
        $el_class = esc_attr($instance['el_class']);

        $the_query = new WP_Query(array('post_type' => 'client', 'posts_per_page' => $posts_per_page));
        if ($the_query->have_posts()) :
            ?>
            <div class="row carousel sympathy-client sympathy-client-widget <?php echo esc_attr($el_class); ?>">
                <div class="col-xs-12 col-sm-12 col-md-12">
                    <ul class="client-slider owl-carousel">
                        <?php
                        if ($the_query->have_posts()) :
                            while ($the_query->have_posts()) : $the_query->the_post();
                                $post_id = get_the_ID();
                                $thumb_id = get_post_thumbnail_id($post_id);
                                $alt = get_post_meta($thumb_id, '_wp_attachment_image_alt', true);
                                $url = wp_get_attachment_url($thumb_id);
                                ob_start();
                                ?>
                                <li>
                                    <a href="javascript:;"><img src="<?php echo esc_url($url); ?>" alt="<?php echo esc_attr($alt); ?>"/></a>
                                </li>                   
                                <?php
                                $content_show = ob_get_contents();
                                ob_clean();
                                ob_end_flush();
                                echo $content_show;
                            endwhile;
                        endif;
                        ?> 
                    </ul>
                </div>
            </div>
            <?php
        endif;
        wp_reset_postdata();
        echo $after_widget;
    }

}
