<?php
// Create Widget
add_action('widgets_init', 'register_photo_gallery_widget');

function register_photo_gallery_widget() {
    register_widget('SYMPATHY_Photo_Gallery_Widget');
}

/**
 * Create class Sympathy_Client_Widget
 */
class SYMPATHY_Photo_Gallery_Widget extends WP_Widget {

    function __construct() {
        parent::__construct(
                'sympathy_photo_gallery_widget', // Base ID
                esc_html__('Photo Gallery', 'sympathy'), // Name
                array(
            'classname' => 'gallery-widget sympathy-widget-photo-gallery-list',
            'description' => esc_html__("Displays a photo gallery on the page.", 'sympathy'),
                )
        );
    }

// end constructor

    /**
     * create form option for widget
     */
    function form($instance) {
        parent::form($instance);

        $default = array(
            'title' => esc_html__('Photo Gallery', 'sympathy'),
            'posts_per_page' => '9',
        );

        $instance = wp_parse_args((array) $instance, $default);
        $title = esc_attr($instance['title']);
        $posts_per_page = esc_attr($instance['posts_per_page']);
        $post_gallery_id = isset($instance['post_gallery_id']) ? esc_attr($instance['post_gallery_id']) : '';
        $randomclass_ana = rand(100, 10000);
        $args = array(
            'posts_per_page' => -1,
            'post_type' => 'photo-gallery',
            'post_status' => 'publish',
        );
        $the_query = new WP_Query($args);
        ob_start();
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>" style="display:block;"><?php echo esc_html__('Title', 'sympathy'); ?></label>
            <input class="widefat title" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('posts_per_page')); ?>" style="display:block;"><?php echo esc_html__('Number of client to show', 'sympathy'); ?></label>
            <input class="widefat posts_per_page" id="<?php echo esc_attr($this->get_field_id('posts_per_page')); ?>" name="<?php echo esc_attr($this->get_field_name('posts_per_page')); ?>" type="number" min="1" max="" step="1" value="<?php echo esc_attr($posts_per_page); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('post_gallery_id')); ?>" style="display:block;"><?php echo esc_html__('Choose a Photo Gallery', 'sympathy'); ?></label>
            <select id="<?php echo esc_attr($this->get_field_id('post_gallery_id')); ?>" name="<?php echo esc_attr($this->get_field_name('post_gallery_id')); ?>">
                <?php
                if ($the_query->have_posts()) : while ($the_query->have_posts()) : $the_query->the_post();
                        $selected = ($post_gallery_id == get_the_ID()) ? 'selected="selected"' : '';
                        ?>                        
                        <option <?php echo esc_attr($selected); ?> value="<?php echo get_the_ID(); ?>"><?php echo get_the_title(get_the_ID()); ?></option>
                        <?php
                    endwhile;
                endif;
                ?>
            </select>
        </p>

        <?php
        $content_wid = ob_get_contents();
        ob_clean();
        ob_end_flush();
        echo $content_wid;
    }

    /**
     * save widget form
     */
    function update($new_instance, $old_instance) {
        parent::update($new_instance, $old_instance);

        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['posts_per_page'] = strip_tags($new_instance['posts_per_page']);
        $instance['post_gallery_id'] = strip_tags($new_instance['post_gallery_id']);
        return $instance;
    }

    /**
     * Show widget
     */
    function widget($args, $instance) {
        extract($args);
        $title = apply_filters('widget_title', $instance['title']);
        $posts_per_page = absint($instance['posts_per_page']);
        $post_gallery_id = absint($instance['post_gallery_id']);

        echo $before_widget;
        if (!empty($title)) {
            echo $before_title . $title . $after_title;
        }
        $args_gallery = get_post_meta($post_gallery_id, 'qtc_gallery', true);
        $random_gallery = array_rand($args_gallery, $posts_per_page);        
        ?>
        <ul id="gallerywidget" class="list-unstyled">
            <?php
            foreach ($random_gallery as $value) {
                $post_id = $args_gallery[$value];
                $image_full = wp_get_attachment_url($post_id);
                $image_thumnail = wp_get_attachment_image_src($post_id, 'thumbnail');
                $alt = get_post_meta($post_id, '_wp_attachment_image_alt', true);
                if (!empty($image_thumnail)) {
                    ?>
                    <li data-src="<?php echo esc_url($image_full); ?>">
                        <a href="#">
                            <div class="gallery-wrap sympathy-overlay sympathy-overlay-hover">
                                <div class="sympathy-overlay-panel sympathy-overlay-background sympathy-overlay-background-primary sympathy-flex sympathy-flex-center sympathy-flex-middle">
                                    <span class="fa fa-arrows-alt"></span>
                                </div>
                                <img class="img-icon" src="<?php echo esc_url($image_thumnail[0]); ?>" alt="<?php if (count($alt)) echo esc_attr($alt); ?>">
                            </div>
                        </a>
                    </li>
                    <?php
                }
            }
            ?>
        </ul>
        <?php
        echo $after_widget;
    }

}
