<?php

class SYMPATHY_Featured_Product_Widget extends WC_Widget {

	/**

	 * Constructor

	 */
	function __construct() {

		$this->widget_cssclass = 'woocommerce sympathy-widget-featured-products-list';

		$this->widget_description = esc_html__( "Display featured product on single product.", 'sympathy' );

		$this->widget_id = 'sympathy_featured-products';

		$this->widget_name = esc_html__( 'Featured Products', 'sympathy' );

		$this->settings = array(
			'title' => array(
				'type' => 'text',
				'std' => esc_html__( 'Featured Products List', 'sympathy' ),
				'label' => esc_html__( 'Title', 'sympathy' )
			),
			'posts_per_page' => array(
				'type' => 'number',
				'step' => 1,
				'min' => 1,
				'max' => '',
				'std' => 3,
				'label' => esc_html__( 'Number of products to show', 'sympathy' )
			),
			'orderby' => array(
				'type' => 'select',
				'std' => 'none',
				'label' => esc_html__( 'Order by', 'sympathy' ),
				'options' => array(
					'none' => esc_html__( 'None', 'sympathy' ),
					'comment_count' => esc_html__( 'Comment Count', 'sympathy' ),
					'title' => esc_html__( 'Title', 'sympathy' ),
					'date' => esc_html__( 'Date', 'sympathy' ),
					'ID' => esc_html__( 'ID', 'sympathy' ),
				)
			),
			'order' => array(
				'type' => 'select',
				'std' => 'none',
				'label' => esc_html__( 'Sorting order', 'sympathy' ),
				'options' => array(
					'none' => esc_html__( 'None', 'sympathy' ),
					'asc' => esc_html__( 'ASC', 'sympathy' ),
					'desc' => esc_html__( 'DESC', 'sympathy' ),
				)
			),
			'price' => array(
				'type' => 'checkbox',
				'std' => 1,
				'label' => esc_html__( 'Show product price', 'sympathy' )
			),
			'rating' => array(
				'type' => 'checkbox',
				'std' => 1,
				'label' => esc_html__( 'Show product rating', 'sympathy' )
			),
			'el_class' => array(
				'type' => 'text',
				'std' => '',
				'label' => esc_html__( 'Extra Class', 'sympathy' )
			)
		);
		parent::__construct();
	}

	/**

	 * widget function.

	 *

	 * @see WP_Widget

	 *

	 * @param array $args

	 * @param array $instance

	 */
	function widget( $args, $instance ) {
		global $post;
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		$posts_per_page = absint( $instance['posts_per_page'] );
		$posts_per_page = $posts_per_page > 0 ? $posts_per_page : -1;
		$orderby = esc_attr( $instance['orderby'] );
		$order = esc_attr( $instance['order'] );
		$p = isset( $instance['price'] ) ? $instance['price'] : $this->settings['price']['std'];
		$r = isset( $instance['rating'] ) ? $instance['rating'] : $this->settings['rating']['std'];
		$el_class = esc_attr( $instance['el_class'] );
		echo $before_widget;
		if ( !empty( $title ) ) {
			echo $before_title . $title . $after_title;
		}
		$product = new WC_Product( $post->ID );
		if ( empty( $product ) || !$product->exists() ) {
			return;
		}
		$args = apply_filters( 'woocommerce_featured_products_args', array(
			'posts_per_page' => $posts_per_page,
			'orderby' => $orderby,
			'post_type' => 'product',
			'post_status' => 'publish',
			'meta_key' => '_featured',
			'meta_value' => 'yes'
				) );
		$products = new WP_Query( $args );
		if ( $products->have_posts() ) :
			?>
			<div class="featured sidebar-featured">
				<?php
				while ( $products->have_posts() ) : $products->the_post();
					$post_id = get_the_ID();
					$thumb_id = get_post_thumbnail_id( $post_id );
					$alt = get_post_meta( $thumb_id, '_wp_attachment_image_alt', true );
					$url = wp_get_attachment_url( $thumb_id );
					$image = sympathy_image_resize( $url, 70, 92, false );
					?>
					<div class="col-product-item row">
						<div class="col-image col-md-4 col-sm-4 col-xs-4">
							<div class="product_item_content_image img_inner">
								<a href="<?php the_permalink(); ?>">
									<?php
									if ( !empty( $image ) ) {
										?>
										<img src="<?php echo esc_url( $image ); ?>" alt="<?php if ( count( $alt ) ) echo esc_attr( $alt ); ?>">
										<?php
									}
									?>
								</a>
							</div>
						</div>
						<div class="col-content woo-content col-md-8 col-sm-8 col-xs-8">
							<div class="product_title text-ellipsis">
								<a href="<?php echo esc_url( the_permalink() ); ?>"><?php echo esc_attr( the_title() ); ?></a>
							</div>
							<?php if ( $r ) { ?>
								<div class="product_rating">
									<?php
									do_action( 'woocommerce_template_loop_rating' );
									?>
								</div>
							<?php } ?>
							<?php if ( $p ) { ?>
								<div class="product_price">
									<?php
									do_action( 'woocommerce_template_loop_price' );
									?>
								</div>
							<?php } ?>
							<div class="clear"></div>
						</div>
					</div>
					<?php
				endwhile;
				wp_reset_postdata(); // end of the loop.
				?>
			</div>
			<?php
		endif;
		echo $after_widget;
	}

}

/**

 * Class sympathy_Featured_Product_Widget

 */
function sympathy_register_featured_product_list_widget() {

	register_widget( 'SYMPATHY_Featured_Product_Widget' );
}

add_action( 'widgets_init', 'sympathy_register_featured_product_list_widget' );

