<?php
// Create Widget
add_action('widgets_init', 'register_tabs_news_widget');

function register_tabs_news_widget() {
    register_widget('SYMPATHY_Tabs_News_Widget');
}

/**
 * Create class Sympathy_Client_Widget
 */
class SYMPATHY_Tabs_News_Widget extends WP_Widget {

    function __construct() {
        parent::__construct(
                'sympathy_tabs_news_widget', // Base ID
                esc_html__('Tabs News', 'sympathy'), // Name
                array(
            'classname' => 'tabs-news-widget sympathy-widget-tabs-news-list',
            'description' => esc_html__("Displays Tabs news on the page.", 'sympathy'),
                )
        );
    }

// end constructor

    /**
     * create form option for widget
     */
    function form($instance) {
        parent::form($instance);

        $default = array(
            'title' => esc_html__('Tabs News', 'sympathy'),
            'posts_per_page' => '5',
            'order_by' => 'date',
            'order' => 'DESC',
        );

        $instance = wp_parse_args((array) $instance, $default);
        $title = esc_attr($instance['title']);
        $posts_per_page = esc_attr($instance['posts_per_page']);
        $order_by = esc_attr($instance['order_by']);
        ob_start();
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>" style="display:block;"><?php echo esc_html__('Title', 'sympathy'); ?></label>
            <input class="widefat title" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('posts_per_page')); ?>" style="display:block;"><?php echo esc_html__('Number of client to show', 'sympathy'); ?></label>
            <input class="widefat posts_per_page" id="<?php echo esc_attr($this->get_field_id('posts_per_page')); ?>" name="<?php echo esc_attr($this->get_field_name('posts_per_page')); ?>" type="number" min="1" max="" step="1" value="<?php echo esc_attr($posts_per_page); ?>" />
        </p>


        <?php
        $content_wid = ob_get_contents();
        ob_clean();
        ob_end_flush();
        echo $content_wid;
    }

    /**
     * save widget form
     */
    function update($new_instance, $old_instance) {
        parent::update($new_instance, $old_instance);

        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['posts_per_page'] = strip_tags($new_instance['posts_per_page']);

        return $instance;
    }

    /**
     * Show widget
     */
    function widget($args, $instance) {
        extract($args);
        $title = apply_filters('widget_title', $instance['title']);
        $posts_per_page = absint($instance['posts_per_page']);

        echo $before_widget;
        if (!empty($title)) {
            echo $before_title . $title . $after_title;
        }

        $id = rand(0000, 9999);
        ?>

        <ul class="nav nav-tabs crt-widget-tabs">
            <li class="crt-widget-tabs-tab active"><a data-toggle="tab" href="#recent_<?php echo esc_attr($id); ?>"><?php echo esc_html__('Recents News','sympathy');?></a></li>
            <li class="crt-widget-tabs-tab"><a data-toggle="tab" href="#lastest_<?php echo esc_attr($id); ?>"><?php echo esc_html__('Lastest Cause','sympathy');?></a></li>
        </ul>
        <div class="tab-content crt-widget-tabs-content">
            <div id="recent_<?php echo esc_attr($id); ?>" class="tab-pane fade in active">                   
                <ul id="recent-news-widget-tabs-<?php echo esc_attr($id); ?>" class="list-lastest-news-tabs">
                    <?php
                    $the_query = new WP_Query(array('post_type' => 'post', 'posts_per_page' => $posts_per_page, 'post_status' => 'publish',));
                    if ($the_query->have_posts()) :
                        while ($the_query->have_posts()) {
                            $the_query->the_post();
                            $post_id = get_the_ID();
                            $url = get_permalink($post_id);
                            $date = get_the_date();
                            ob_start();
                            if (!empty($url)) {
                                ?>
                                <li data-src="<?php echo esc_url($url); ?>">							
                                    <a href="<?php echo esc_url($url); ?>"><?php echo get_the_title(); ?></a>
                                    <i class="fa fa-clock-o" aria-hidden="true"></i><?php echo esc_attr($date); ?>
                                    <p><?php echo substr(get_the_content(), 0, 50) . '...'; ?></p>
                                </li>
                                <?php
                            }

                            $content_show = ob_get_contents();
                            ob_clean();
                            ob_end_flush();
                            echo $content_show;
                        }
                    endif;
                    ?>
                </ul>
            </div>
            <div id="lastest_<?php echo esc_attr($id); ?>" class="tab-pane fade">
                <ul id="lastest-news-widget-tabs-<?php echo esc_attr($id); ?>" class="list-lastest-news-tabs">
                    <?php
                    $the_query = new WP_Query(array('post_type' => 'campaign', 'posts_per_page' => $posts_per_page, 'post_status' => 'publish',));
                    if ($the_query->have_posts()) :
                        while ($the_query->have_posts()) {
                            $the_query->the_post();
                            $post_id = get_the_ID();
                            $url = get_permalink($post_id);
                            $date = get_the_date();
                            ob_start();
                            if (!empty($url)) {
                                ?>
                                <li data-src="<?php echo esc_url($url); ?>">							
                                    <a href="<?php echo esc_url($url); ?>"><?php echo get_the_title(); ?></a>
                                    <i class="fa fa-clock-o" aria-hidden="true"></i><?php echo esc_attr($date); ?>
                                    <p><?php echo substr(get_the_content(), 0, 50) . '...'; ?></p>
                                </li>
                                <?php
                            }

                            $content_show = ob_get_contents();
                            ob_clean();
                            ob_end_flush();
                            echo $content_show;
                        }
                    endif;
                    ?>
                </ul>
            </div>                
        </div>

        <?php
        wp_reset_postdata();

        echo $after_widget;
    }

}
